@@ -143,37 +143,21 @@ public:
     /// Optiosn used around the generator code
     enum Option {
         NoOption                 = 0x00000000,
-        BoxedPrimitive           = 0x00000001,
-        ExcludeConst             = 0x00000002,
-        ExcludeReference         = 0x00000004,
-        UseNativeIds             = 0x00000008,
+        ExcludeConst             = 0x00000001,
+        ExcludeReference         = 0x00000002,
 
-        EnumAsInts               = 0x00000010,
-        SkipName                 = 0x00000020,
-        NoCasts                  = 0x00000040,
-        SkipReturnType           = 0x00000080,
-        OriginalName             = 0x00000100,
-        ShowStatic               = 0x00000200,
-        UnderscoreSpaces         = 0x00000400,
-        ForceEnumCast            = 0x00000800,
-        ArrayAsPointer           = 0x00001000,
-        VirtualCall              = 0x00002000,
-        SkipTemplateParameters   = 0x00004000,
-        SkipAttributes           = 0x00008000,
-        OriginalTypeDescription  = 0x00010000,
-        SkipRemovedArguments     = 0x00020000,
-        IncludeDefaultExpression = 0x00040000,
-        NoReturnStatement        = 0x00080000,
-        NoBlockedSlot            = 0x00100000,
+        EnumAsInts               = 0x00000004,
+        SkipName                 = 0x00000008,
+        SkipReturnType           = 0x00000010,
+        OriginalName             = 0x00000020,
+        VirtualCall              = 0x00000040,
+        OriginalTypeDescription  = 0x00000080,
+        SkipRemovedArguments     = 0x00000100,
 
-        SuperCall                = 0x00200000,
+        SkipDefaultValues        = 0x00000200,
 
-        GlobalRefJObject         = 0x00100000,
-
-        SkipDefaultValues        = 0x00400000,
-
-        WriteSelf                = 0x00800000,
-        ExcludeMethodConst       = 0x01000000,
+        WriteSelf                = 0x00000400,
+        ExcludeMethodConst       = 0x00000800,
 
         ForceValueType           = ExcludeReference | ExcludeConst
     };
@@ -241,9 +225,6 @@ public:
     QString getFileNameBaseForSmartPointer(const AbstractMetaType *smartPointerType,
                                            const AbstractMetaClass *smartPointerClass) const;
 
-    /// Returns the number of generated items
-    int numGenerated() const;
-
     /// Returns the generator's name. Used for cosmetic purposes.
     virtual const char* name() const = 0;
 
@@ -284,9 +265,6 @@ public:
 
     void replaceTemplateVariables(QString &code, const AbstractMetaFunction *func);
 
-    // QtScript
-    QSet<QString> qtMetaTypeDeclaredTypeNames() const;
-
     /**
     *   Returns the license comment to be prepended to each source file generated.
     */
